.. _installation:

Installation
============

You can install QCRAFT AutoScheduler and all its dependencies using pip::

    pip install autoscheduler

You can also install from source by cloning the repository and installing from source::

    git clone https://github.com/Qcraft-UEx/QCRAFT-AutoScheduler.git
    cd autoscheduler
    pip install .